**Example 1: 重置root账号权限**



Input: 

```
tccli cdb ResetRootAccount --cli-unfold-argument  \
    --InstanceId cdb-ksixa
```

Output: 
```
{
    "Response": {
        "RequestId": "6EF60BEC-0242-43AF-BB20-270359FB54A7"
    }
}
```

